Label

Struct Label 

pub struct Label(/* private fields */);
W Styleable and focusable read-only text widget.

Optionally can be the label of a target widget, if set the target widget is focused when the label is focused.

Shorthand

The widget macro supports the shorthand that sets the txt and target properties.

let label = Label!("txt", "target");

Implementations

Source

impl Label

pub fn widget_new() -> Self

Start building a new instance.

pub fn widget_type() -> WidgetType

Gets the widget type info.

Source

impl Label

pub fn style_fn(&self, style_fn: impl IntoVar<StyleFn>)

P Extends or replaces the widget style.

Properties and when conditions in the style are applied to the widget. Style instances extend the contextual style by default, you can set replace on a style to true to fully replace.

Source

impl Label

pub fn target(&self, target: impl IntoVar<WidgetId>)

P Defines the widget the label is for.

When the label is pressed the widget or the first focusable child of the widget is focused. Accessibility metadata is also set so the target widget is marked as labelled-by this widget in the view-process.

Source

impl Label

pub fn mnemonic_underline(&self, enabled: impl IntoVar<bool>)

P Only draw underline under active mnemonic char in labels.

When enabled this overrides underline_skip in labels, only the char defined by get_mnemonic_char is underlined.

Note that underline must also be set to a visible state in context.

Methods from Deref<Target = StyleMix<Text>>

pub fn style_intrinsic( &mut self, style_var: ContextVar<StyleFn>, style_fn: PropertyId, )

Setup the style build.