FieldStyle

Struct FieldStyle 

pub struct FieldStyle(/* private fields */);
W Text input style that shows data notes, info, warn and error.

You can also set the field_help property in text inputs with this style to set a text that shows in place of the data notes when there are none.

Implementations

Source

impl FieldStyle

pub fn widget_new() -> Self

Start building a new instance.

pub fn widget_type() -> WidgetType

Gets the widget type info.

Methods from Deref<Target = DefaultStyle>

pub fn placeholder_txt(&self, txt: impl IntoVar<Txt>)

P Text shown when the txt is empty.

The placeholder has the same text style as the parent widget, with 50% opacity. You can use the placeholder to use a custom widget placeholder.

pub fn placeholder(&self, placeholder: impl IntoUiNode)

P Widget shown when the txt is empty.

The placeholder can be any widget, the Text! widget is recommended.

Methods from Deref<Target = Style>

pub fn widget_build(&mut self) -> StyleBuilder

Build the style.

pub fn replace(&self, replace: impl IntoValue<bool>)

B Fully replace the contextual style.

This is not enabled by default, if set to true the contextual style properties are removed.

pub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)

B Set in the default properties of a named style to define the contextual variable for that style.

During widget instantiation, if this is set by default in a style the contextual style is used as the defaults and only the properties set on the style instance replace them.

This property is part of the named styles pattern, see impl_named_style_fn! for more details.

Note that this property expects a ContextVar<StyleFn> as a value, not a variable directly, it will also only work if set in the default properties of a style type.