pub struct Label(/* private fields */);Expand description
Implementations
Sourceimpl Label
impl Label
Sourcepub fn widget_new() -> Self
pub fn widget_new() -> Self
Start building a new instance.
Sourcepub fn widget_type() -> WidgetType
pub fn widget_type() -> WidgetType
Gets the widget type info.
Sourceimpl Label
impl Label
Sourcepub fn target(&self, target: impl IntoVar<WidgetId>)
pub fn target(&self, target: impl IntoVar<WidgetId>)
P Defines the widget the label is for.
When the label is pressed the widget or the first focusable child of the widget is focused. Accessibility metadata is also set so the target widget is marked as labelled-by this widget in the view-process.
Sourceimpl Label
impl Label
Sourcepub fn mnemonic_underline(&self, enabled: impl IntoVar<bool>)
pub fn mnemonic_underline(&self, enabled: impl IntoVar<bool>)
P Only draw underline under active mnemonic char in labels.
When enabled this overrides underline_skip in labels, only the char defined by get_mnemonic_char is underlined.
Note that underline must also be set to a visible state in context.
Methods from Deref<Target = StyleMix<Text>>
Sourcepub fn style_intrinsic(
&mut self,
style_var: ContextVar<StyleFn>,
style_fn: PropertyId,
)
pub fn style_intrinsic( &mut self, style_var: ContextVar<StyleFn>, style_fn: PropertyId, )
Setup the style build.