pub struct FieldStyle(/* private fields */);Expand description
W Text input style that shows data notes, info, warn and error.
You can also set the field_help property in text inputs with this style to set a text that
shows in place of the data notes when there are none.
Implementations
Sourceimpl FieldStyle
impl FieldStyle
Sourcepub fn widget_new() -> Self
pub fn widget_new() -> Self
Start building a new instance.
Sourcepub fn widget_type() -> WidgetType
pub fn widget_type() -> WidgetType
Gets the widget type info.
Methods from Deref<Target = DefaultStyle>
Sourcepub fn placeholder_txt(&self, txt: impl IntoVar<Txt>)
pub fn placeholder_txt(&self, txt: impl IntoVar<Txt>)
P Text shown when the txt is empty.
The placeholder has the same text style as the parent widget, with 50% opacity.
You can use the placeholder to use a custom widget placeholder.
Sourcepub fn placeholder(&self, placeholder: impl IntoUiNode)
pub fn placeholder(&self, placeholder: impl IntoUiNode)
P Widget shown when the txt is empty.
The placeholder can be any widget, the Text! widget is recommended.
Methods from Deref<Target = Style>
Sourcepub fn widget_build(&mut self) -> StyleBuilder
pub fn widget_build(&mut self) -> StyleBuilder
Build the style.
Sourcepub fn replace(&self, replace: impl IntoValue<bool>)
pub fn replace(&self, replace: impl IntoValue<bool>)
B Fully replace the contextual style.
This is not enabled by default, if set to true the contextual style properties are removed.
Sourcepub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)
pub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)
B Set in the default properties of a named style to define the contextual variable for that style.
During widget instantiation, if this is set by default in a style the contextual style is used as the defaults and only the properties set on the style instance replace them.
This property is part of the named styles pattern, see impl_named_style_fn! for more details.
Note that this property expects a ContextVar<StyleFn> as a value, not a variable directly, it will also only work if
set in the default properties of a style type.